@@ -25,14 +25,13 @@
 #include <gtk/gtk.h>
 #include <NvCtrlAttributes.h>
 
-#include "dfp_banner.h"
+#include "ctkimage.h"
 
 #include "ctkdisplaydevice-dfp.h"
 
 #include "ctkimagesliders.h"
 #include "ctkconfig.h"
 #include "ctkhelp.h"
-#include "ctkutils.h"
 
 
 static GtkWidget *make_scaling_radio_button(CtkDisplayDeviceDfp
@@ -72,7 +71,6 @@ static void dfp_update_received(GtkObject *object, gpointer arg1,
 
 #define __SCALING (1<<0)
 #define __DITHERING (1<<1)
-#define __INFO (1<<2)
 
 
 static const char *__scaling_help =
@@ -87,10 +85,6 @@ static const char *__dithering_help =
 "properly display on a flatpanel; this option allows "
 "you to control the dithering behavior.";
 
-static const char *__info_help = 
-"This section describes basic informations about the "
-"DVI connection to the digital flat panel.";
-
 
 GType ctk_display_device_dfp_get_type(void)
 {
@@ -131,7 +125,7 @@ GtkWidget* ctk_display_device_dfp_new(NvCtrlAttributeHandle *handle,
 {
     GObject *object;
     CtkDisplayDeviceDfp *ctk_display_device_dfp;
-    GtkWidget *image;
+    GtkWidget *banner;
     GtkWidget *frame;
     GtkWidget *hbox, *vbox;
     GtkWidget *label;
@@ -143,12 +137,8 @@ GtkWidget* ctk_display_device_dfp_new(NvCtrlAttributeHandle *handle,
     GtkWidget *radio3;
     GtkWidget *alignment;
     
-    GtkWidget *table;
-    
     ReturnStatus ret;
     
-    guint8 *image_buffer = NULL;
-    const nv_image_t *img;    
     gint val, i;
 
     object = g_object_new(CTK_TYPE_DISPLAY_DEVICE_DFP, NULL);
@@ -162,26 +152,9 @@ GtkWidget* ctk_display_device_dfp_new(NvCtrlAttributeHandle *handle,
     gtk_box_set_spacing(GTK_BOX(object), 10);
 
     /* banner */
-    
-    hbox = gtk_hbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(object), hbox, FALSE, FALSE, 0);
 
-    frame = gtk_frame_new(NULL);
-    gtk_box_pack_start(GTK_BOX(hbox), frame, FALSE, FALSE, 0);
-
-    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
-    
-    img = &dfp_banner_image;
-    
-    image_buffer = decompress_image_data(img);
-    
-    image = gtk_image_new_from_pixbuf
-        (gdk_pixbuf_new_from_data(image_buffer, GDK_COLORSPACE_RGB,
-                                  FALSE, 8, img->width, img->height,
-                                  img->width * img->bytes_per_pixel,
-                                  free_decompressed_image, NULL));
-
-    gtk_container_add(GTK_CONTAINER(frame), image);
+    banner = ctk_banner_image_new(BANNER_ARTWORK_DFP);
+    gtk_box_pack_start(GTK_BOX(object), banner, FALSE, FALSE, 0);
     
     /*
      * create the reset button (which we need while creating the
@@ -210,64 +183,11 @@ GtkWidget* ctk_display_device_dfp_new(NvCtrlAttributeHandle *handle,
                            "The Reset Hardware Defaults button restores "
                            "the DFP settings to their default values.");
 
-    /* create the hbox to store dfp info, scaling and dithering */
+    /* create the hbox to store scaling and dithering */
 
     hbox = gtk_hbox_new(FALSE, FRAME_PADDING);
     gtk_box_pack_start(GTK_BOX(object), hbox, TRUE, TRUE, FRAME_PADDING);
 
-    /* DFP info */
-    ret = NvCtrlGetDisplayAttribute(handle, display_device_mask,
-                                    NV_CTRL_FLATPANEL_CHIP_LOCATION, &val);
-    if (ret == NvCtrlSuccess) {
-        char *chip_location, *link, *signal;
-        gint tmp;
-        
-        /* NV_CTRL_FLATPANEL_CHIP_LOCATION */
-        ret = NvCtrlGetDisplayAttribute(handle, display_device_mask, 
-                                        NV_CTRL_FLATPANEL_CHIP_LOCATION, &tmp);
-        chip_location = NULL;
-        if (ret == NvCtrlSuccess) {
-            if (tmp == NV_CTRL_FLATPANEL_CHIP_LOCATION_INTERNAL) chip_location = "Internal";
-            if (tmp == NV_CTRL_FLATPANEL_CHIP_LOCATION_EXTERNAL) chip_location = "External";
-        }
-         
-        ret = NvCtrlGetDisplayAttribute(handle, display_device_mask, 
-                                        NV_CTRL_FLATPANEL_LINK, &tmp);
-        link = NULL;
-        if (ret == NvCtrlSuccess) {
-            if (tmp == NV_CTRL_FLATPANEL_LINK_SINGLE) link = "Single";
-            if (tmp == NV_CTRL_FLATPANEL_LINK_DUAL) link = "Dual";
-        }
-        
-        ret = NvCtrlGetDisplayAttribute(handle, display_device_mask, 
-                                        NV_CTRL_FLATPANEL_SIGNAL, &tmp);
-        signal = NULL;
-        if (ret == NvCtrlSuccess) {
-            if (tmp == NV_CTRL_FLATPANEL_SIGNAL_LVDS) signal = "LVDS";
-            if (tmp == NV_CTRL_FLATPANEL_SIGNAL_TMDS) signal = "TMDS";
-        }
-          
-        frame = gtk_frame_new("Flat Panel Information");
-        gtk_box_pack_start(GTK_BOX(hbox), frame, TRUE, TRUE, 0);
-        
-        table = gtk_table_new(3, 2, FALSE);
-        gtk_container_add(GTK_CONTAINER(frame), table);
-        
-        gtk_table_set_row_spacings(GTK_TABLE(table), 3);
-        gtk_table_set_col_spacings(GTK_TABLE(table), 15);
-
-        gtk_container_set_border_width(GTK_CONTAINER(table), 5);
-
-    
-        add_table_row(table, 0, 0, "Chip location:", chip_location);
-        add_table_row(table, 1, 0, "DVI connection link:", link);
-        add_table_row(table, 2, 0, "Signal:", signal);
-        
-        ctk_display_device_dfp->active_attributes |= __INFO;
-    }
-    else
-        ctk_display_device_dfp->active_attributes &= ~__INFO;
-    
     /* FlatPanel Scaling */
     
     ret = NvCtrlGetDisplayAttribute(handle, display_device_mask,
@@ -811,28 +731,6 @@ GtkTextBuffer *ctk_display_device_dfp_create_help(GtkTextTagTable *table,
     
     ctk_help_title(b, &i, "%s Help", ctk_display_device_dfp->name);
     
-    if (ctk_display_device_dfp->active_attributes & __INFO) {
-        ctk_help_heading(b, &i, "FlatPanel Information");
-        ctk_help_para(b, &i, __info_help);
-        
-        ctk_help_term(b, &i, "Chip Location");
-        ctk_help_para(b, &i, "Report whether the flatpanel is driven by "
-                      "the on-chip controller (internal), or a "
-                      " separate controller chip elsewhere on the "
-                      "graphics board (external)");
-                      
-        ctk_help_term(b, &i, "Link");
-        ctk_help_para(b, &i, "Report whether the specified display device "
-                      "is driven by a single link or dual link DVI "
-                      "connection.");
-        
-        ctk_help_term(b, &i, "Signal");
-        ctk_help_para(b, &i, "Report whether the flatpanel is driven by "
-                       "an LVDS or TMDS signal");
-        
-        ret = TRUE;
-    }
-    
     if (ctk_display_device_dfp->active_attributes & __SCALING) {
         ctk_help_heading(b, &i, "FlatPanel Scaling");
         ctk_help_para(b, &i, __scaling_help);
