@@ -3,7 +3,7 @@
 #include "image.h"
 
 static const nv_image_t gvo_banner_left_image = {
-  70, 60, 3,
+  70, 60, 3, 0,
   "\11S]\21Xc\22`k\23hv\25p\177\27x\206\30}\214\32\200\220\33\200\221\33\275"
   "\201\221\33\10`k\25iu\26s\200\31\177\214\33\211\231\35\222\242\37\227\251"
   "\40\232\255!\202\234\256!\274\235\257!\11ly\27u\203\32\201\220\34\217\240"
